@@ -21,29 +21,7 @@ extern "C" {
 #endif
 
 #ifndef HAVE_SNPRINTF
-// This is the only signature that snprintf is called with in grap.
-// It's concievable that someone could smash the stack here, but
-// there's not much privlege to gain, and I'd be impressed enough if
-// you could print a float that caused a stack overflow and error that
-// you can break the code.
-inline int snprintf(char *s, int lim, const char *fmt, double d) {
-    int tot;
-
-#ifdef SPRINTF_NOT_INT
-    // For some reason some old versions of SunOS have an sprintf that
-    // doesn't return an int.  In this case, we can't bounds check at all.
-    
-    sprintf(s,fmt,d);
-    tot = lim;
-#else    
-    if ( (tot = sprintf(s,fmt,d)) > lim ) {
-	cerr << "Bad format to internal sprintf crashed the stack" << endl;
-	abort();
-    }
-#endif
-
-    return tot;
-}
+#include "snprintf.h"
 #else
 // AIX seems to have snprintf, but not prototype it..
 #ifndef SNPRINTF_DECLARED
@@ -76,16 +54,18 @@ class keyword;
 
 #ifdef HAVE_UNORDERED_MAP
 #include <unordered_map>
-#define HASH_MAP unordered_map
+
+typedef HASH_SPACE::unordered_map<string, double *> doubleDictionary;
+typedef HASH_SPACE::unordered_map<string, coord *> coordinateDictionary;
+typedef HASH_SPACE::unordered_map<string, line *> lineDictionary;
+typedef HASH_SPACE::unordered_map<string, macro *> macroDictionary;
+typedef HASH_SPACE::unordered_map<string, keyword> keywordDictionary;
 #else
-#define HASH_MAP hash_map
 #ifdef HAVE_HASH_MAP
 #include <hash_map>
 #else
 #include <ext/hash_map>
 #endif
-#endif
-
 // A functor for hashing strings - it is an adapter to get to the
 // standard library char * hash function.
 class Strhash : public unary_function<const string&, size_t> {
@@ -97,11 +77,13 @@ public:
     }
 };
 
-typedef HASH_SPACE::HASH_MAP<string, double *, Strhash> doubleDictionary;
-typedef HASH_SPACE::HASH_MAP<string, coord *, Strhash> coordinateDictionary;
-typedef HASH_SPACE::HASH_MAP<string, line *, Strhash> lineDictionary;
-typedef HASH_SPACE::HASH_MAP<string, macro *, Strhash> macroDictionary;
-typedef HASH_SPACE::HASH_MAP<string, keyword, Strhash> keywordDictionary;
+typedef HASH_SPACE::hash_map<string, double *, Strhash> doubleDictionary;
+typedef HASH_SPACE::hash_map<string, coord *, Strhash> coordinateDictionary;
+typedef HASH_SPACE::hash_map<string, line *, Strhash> lineDictionary;
+typedef HASH_SPACE::hash_map<string, macro *, Strhash> macroDictionary;
+typedef HASH_SPACE::hash_map<string, keyword, Strhash> keywordDictionary;
+#endif
+
 #else
 #include <map>
 typedef less<string> Strcmp;
@@ -151,7 +133,7 @@ class for_descriptor {
     string *anything;
     for_descriptor() : 
 	loop_var(0), dir(0), limit(0.0), by(0.0), by_op(0), anything(0) { }
-    for_descriptor(double *lv, int d, double l, int b, int bo, string *a) :
+    for_descriptor(double *lv, int d, double l, double b, int bo, string *a) :
 	loop_var(lv), dir(d), limit(l), by(b), by_op(bo), anything(a) { }
     ~for_descriptor() {
 	if ( anything) {
